# survtype

Package: survtype

Type: Package

Title: Subtype Identification with Survival Data

Description: Subtypes are defined as groups of samples that have distinct molecular and clinical features. Genomic data can be analyzed for discovering patient subtypes, associated with clinical data, especially for survival information. This package is aimed to identify subtypes that are both clinically relevant and biologically meaningful.

Version: 1.3.1

Date: 2019-12-18

Author: Dongmin Jung

Maintainer: Dongmin Jung <dmdmjung@gmail.com>

Depends: SummarizedExperiment, pheatmap, survival, survminer, clustvarsel, stats, utils

Suggests: maftools, scales, knitr

License: Artistic-2.0

biocViews: Software, StatisticalMethod, GeneExpression, Survival, Clustering, Sequencing, Coverage

NeedsCompilation: no





